@@ -21,12 +21,21 @@
 #include <QDir>
 #include <QQuickView>
 
+#include <libintl.h>
+
+#include "config.hpp"
 
 int main(int argc, char *argv[])
 {
     QGuiApplication *app = new QGuiApplication(argc, (char**)argv);
+    app->setOrganizationName("calendar.ubports");
     app->setApplicationName("calendar.ubports");
 
+    std::string domainDir = localeDirectory().toStdString();
+
+    textdomain("lomiri-calendar-app");
+    bindtextdomain("lomiri-calendar-app", domainDir.c_str());
+    bind_textdomain_codeset ("lomiri-calendar-app", "UTF-8");
 
     QQuickView *view = new QQuickView();
     view->setSource(QUrl("qrc:/calendar.qml"));
