@@ -17,5 +17,9 @@
  */
 .pragma library
 
-var ViewTypeWeek = 0;
-var ViewTypeDay = 1;
+const ViewTypeAgenda = 0;
+const ViewTypeDay = 1;
+const ViewTypeWeek = 2;
+const ViewTypeMonth = 3;
+const ViewTypeYear = 4;
+
